API
===

.. contents::

This part of the documentation documents all the public classes and functions
in Mixer.


Common interface
----------------

.. autoclass:: mixer.main.Mixer
   :members:
   :inherited-members:

.. autoclass:: mixer.main.GenFactory
   :members:


Set values
----------
.. autoclass:: mixer.mix_types.Field


Force a random values
---------------------
.. autoclass:: mixer.mix_types.Random


Force a fake values
-------------------
.. autoclass:: mixer.mix_types.Fake


Select a relation from database
-------------------------------
.. autoclass:: mixer.mix_types.Select


Virtual mixed object
--------------------
.. autoclass:: mixer.mix_types.Mix
